@@ -1,13 +1,14 @@
 package UV;
 
-our $VERSION = '1.000005';
+our $VERSION = '1.000006';
 our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
 
 use strict;
 use warnings;
-
+use Carp ();
 use Exporter qw(import);
+use Math::Int64 ();
+use XS::Object::Magic ();
 require XSLoader;
 XSLoader::load('UV', $XS_VERSION);
 
@@ -17,6 +18,26 @@ our @EXPORT_OK = (
     qw(check timer),
 );
 
+# _parse_args (static, private)
+sub _parse_args {
+    my $args;
+    if ( @_ == 1 && ref $_[0] ) {
+        my %copy = eval { %{ $_[0] } }; # try shallow copy
+        Carp::croak("Argument to method could not be dereferenced as a hash") if $@;
+        $args = \%copy;
+    }
+    elsif (@_==1 && !ref($_[0])) {
+        $args = {single_arg => $_[0]};
+    }
+    elsif ( @_ % 2 == 0 ) {
+        $args = {@_};
+    }
+    else {
+        Carp::croak("Method got an odd number of elements");
+    }
+    return $args;
+}
+
 sub check {
     require UV::Check;
     return UV::Check->new(@_);
