@@ -1,27 +1,23 @@
 package UV::Check;
 
-our $VERSION = '1.000005';
-$VERSION = eval $VERSION;
+our $VERSION = '1.000006';
 
 use strict;
 use warnings;
-use Moo;
-extends 'UV::Handle';
-
 use Carp ();
 use Exporter qw(import);
-use UV::Loop;
+use parent 'UV::Handle';
 
-sub BUILD {
+sub _after_new {
     my ($self, $args) = @_;
-    # add to the default set of events for a Handle object
     $self->_add_event('check', $args->{on_check});
-
-    unless (exists($args->{loop}) && UV::Loop::_is_a_loop($args->{loop})) {
-        $args->{loop} = UV::Loop->default();
-    }
-    $self->_init($args->{loop});
-    $self->{_loop} = $args->{loop};
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
 }
 
 sub start {
@@ -29,7 +25,17 @@ sub start {
     if (@_) {
         $self->on('check', shift);
     }
-    return $self->_start();
+    my $res;
+    my $err = do { #catch
+        local $@;
+        eval {
+            $res = $self->_start();
+            1;
+        }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $res;
 }
 
 1;
@@ -55,7 +61,12 @@ UV::Check - Check handles in libuv
 
   # Use a different loop
   my $loop = UV::Loop->new(); # non-default loop
-  my $check = UV::Check->new($loop);
+  my $check = UV::Check->new(
+    loop => $loop,
+    on_alloc => sub {say "alloc!"},
+    on_close => sub {say "close!"},
+    on_check => sub {say "check!"},
+  );
 
   # setup the check callback:
   $check->on(check => sub {say "We're CHECKING!!!"});
@@ -104,7 +115,12 @@ following extra methods available.
 
     my $check = UV::Check->new();
     # Or tell it what loop to initialize against
-    my $check = UV::Check->new($loop);
+    my $check = UV::Check->new(
+        loop => $loop,
+        on_alloc => sub {say "alloc!"},
+        on_close => sub {say "close!"},
+        on_check => sub {say "check!"},
+    );
 
 This constructor method creates a new L<UV::Check> object and
 L<initializes|http://docs.libuv.org/en/v1.x/check.html#c.uv_check_init> the
