@@ -1,32 +1,13 @@
 package UV::Handle;
 
-our $VERSION = '1.000005';
-$VERSION = eval $VERSION;
+our $VERSION = '1.000006';
 
 use strict;
 use warnings;
-use Moo;
-
+use Carp ();
 use Exporter qw(import);
-use UV;
-
-our @EVENTS = (qw(alloc close));
-
-has data => (is => 'rw');
-
-sub BUILD {
-    my ($self, $args) = @_;
-    $self->{_closed} = 0;
-    $self->{_events} = [qw(alloc close)];
-    for my $event (@EVENTS) {
-        $self->on($event, $args->{"on_$event"});
-    }
-}
-
-sub DEMOLISH {
-    my ($self, $in_global_destruction) = @_;
-    $self->_destruct($self->closed());
-}
+use UV ();
+use UV::Loop ();
 
 sub _add_event {
     my ($self, $event, $cb) = @_;
@@ -35,16 +16,77 @@ sub _add_event {
     $self->on($event, $cb);
 }
 
+sub new {
+    my $self = bless {}, shift;
+    my $args = UV::_parse_args(@_);
+    $self->{_closed} = 0;
+    $self->{_events} = [qw(alloc close)];
+    $self->on('alloc', $args->{on_alloc});
+    $self->on('close', $args->{on_close});
+    $self->{data} = $args->{data};
+
+    my $loop = $args->{loop} || $args->{single_arg};
+    unless ($loop && UV::Loop::_is_a_loop($loop)) {
+        $loop = UV::Loop->default();
+    }
+    $self->{_loop} = $loop;
+    if ($self->can('_after_new')) {
+        $self->_after_new($args);
+    }
+    return $self;
+}
+
+sub DESTROY {
+    my $self = shift;
+    return unless $self->_has_struct();
+    $self->stop() if ($self->can('stop') && !$self->closing() && !$self->closed());
+
+    my $err = do { # catch
+        local $@;
+        eval { $self->_destruct($self->closed()); 1; }; # try
+        $@;
+    };
+    warn $err if $err;
+}
+
+sub active {
+    my $self = shift;
+    return 0 unless $self->_has_struct();
+    return 0 if $self->closed() || $self->closing();
+    my $val = 0;
+    my $err = do { # catch
+        local $@;
+        eval { $val = $self->_active(); 1; }; # try
+        $@;
+    };
+    Carp::croak($err) if $err;
+    return $val;
+}
+
 sub close {
     my $self = shift;
     $self->on('close', @_) if @_; # set the callback ahead of time if exists
-    return if $self->closed();
     return unless $self->_has_struct();
-    return $self->_close();
+
+    return if $self->closed() || $self->closing();
+    $self->stop() if $self->can('stop');
+    my $err = do { # catch
+        local $@;
+        eval { $self->_close(); 1; }; # try
+        $@;
+    };
+    Carp::croak($err) if $err;
 }
 
 sub closed { return (shift->{_closed})? 1: 0; }
 
+sub data {
+    my $self = shift;
+    return $self->{data} unless @_;
+    $self->{data} = shift;
+    return $self;
+}
+
 sub loop { return shift->{_loop}; }
 
 sub on {
@@ -172,10 +214,8 @@ L<UV::Handle> implements the following attributes.
     $handle = $handle->data(undef);
     my $data = $handle->data();
 
-The L<data|http://docs.libuv.org/en/v1.x/handle.html#c.uv_handle_t.data>
-attribute allows you to store some information along with your L<UV::Handle>
-object. Since libuv does not make use of this attribute in any way, you're free
-to use it for your own purposes.
+The C<data> attribute allows you to store some information along with your
+L<UV::Handle> object that you can for your own purposes.
 
 =head2 loop
 
@@ -186,18 +226,6 @@ The L<loop|http://docs.libuv.org/en/v1.x/handle.html#c.uv_handle_t.loop>
 attribute is a B<read-only> attribute that returns the L<UV::Loop> object this
 handle was initialized with.
 
-=head2 type
-
-    # read-only attribute
-    my $int = $handle->type();
-    if ($int == UV::Handle::UV_TIMER) {
-        say "This handle is a timer";
-    }
-
-The L<type|http://docs.libuv.org/en/v1.x/handle.html#c.uv_handle_t.type>
-attribute is a B<read-only> attribute that returns the corresponding libuv
-handle type constant.
-
 =head1 METHODS
 
 L<UV::Handle> makes the following methods available.
@@ -257,7 +285,7 @@ C<< status = UV::UV_ECANCELED >>.
     # are we officially closed?
     my $int = $handle->closed();
 
-Read-only method to let us know if the handle is closed.
+B<Read-only> method to let us know if the handle is closed.
 
 =head2 closing
 
@@ -278,20 +306,6 @@ method returns non-zero if the handle is referenced, zero otherwise.
 
 See L<Reference Counting|http://docs.libuv.org/en/v1.x/handle.html#refcount>.
 
-=head2 is_active
-
-    # simply a synonym for ->active()
-    my $int = $handle->is_active();
-
-A synonym for L<UV::Handle/"active">.
-
-=head2 is_closing
-
-    # simply a synonym for ->closing()
-    my $int = $handle->is_closing();
-
-A synonym for L<UV::Handle/"closing">.
-
 =head2 on
 
     # set a close event callback to print the handle's data attribute
