@@ -1,27 +1,26 @@
 package UV::Idle;
 
-our $VERSION = '1.000005';
-$VERSION = eval $VERSION;
+our $VERSION = '1.000006';
 
 use strict;
 use warnings;
-use Moo;
-extends 'UV::Handle';
+use Exporter qw(import);
+use parent 'UV::Handle';
 
 use Carp ();
-use Exporter qw(import);
-use UV::Loop;
 
-sub BUILD {
+sub _after_new {
     my ($self, $args) = @_;
     # add to the default set of events for a Handle object
-    $self->_add_event('idle', $args->{on_poll});
+    $self->_add_event('idle', $args->{on_idle});
 
-    unless (exists($args->{loop}) && UV::Loop::_is_a_loop($args->{loop})) {
-        $args->{loop} = UV::Loop->default();
-    }
-    $self->_init($args->{loop});
-    $self->{_loop} = $args->{loop};
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
 }
 
 sub start {
@@ -29,7 +28,17 @@ sub start {
     if (@_) {
         $self->on('idle', shift);
     }
-    return $self->_start();
+    my $res;
+    my $err = do { #catch
+        local $@;
+        eval {
+            $res = $self->_start();
+            1;
+        }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $res;
 }
 
 1;
@@ -55,7 +64,12 @@ UV::Idle - Idle handles in libuv
 
   # Use a different loop
   my $loop = UV::Loop->new(); # non-default loop
-  my $idle = UV::Idle->new($loop);
+  my $idle = UV::Idle->new(
+    loop => $loop,
+    on_alloc => sub {say "alloc!"},
+    on_close => sub {say "close!"},
+    on_idle => sub {say "idle!"},
+  );
 
   # setup the idle callback:
   $idle->on(idle => sub {say "We're IDLING!!!"});
@@ -112,7 +126,12 @@ following extra methods available.
 
     my $idle = UV::Idle->new();
     # Or tell it what loop to initialize against
-    my $idle = UV::Idle->new($loop);
+    my $idle = UV::Idle->new(
+        loop => $loop,
+        on_alloc => sub {say "alloc!"},
+        on_close => sub {say "close!"},
+        on_idle => sub {say "idle!"},
+    );
 
 This constructor method creates a new L<UV::Idle> object and
 L<initializes|http://docs.libuv.org/en/v1.x/idle.html#c.uv_idle_init> the
