@@ -1,27 +1,24 @@
 package UV::Prepare;
 
-our $VERSION = '1.000005';
-$VERSION = eval $VERSION;
+our $VERSION = '1.000006';
 
 use strict;
 use warnings;
-use Moo;
-extends 'UV::Handle';
-
 use Carp ();
 use Exporter qw(import);
-use UV::Loop;
+use parent 'UV::Handle';
 
-sub BUILD {
+sub _after_new {
     my ($self, $args) = @_;
-    # add to the default set of events for a Handle object
     $self->_add_event('prepare', $args->{on_prepare});
 
-    unless (exists($args->{loop}) && UV::Loop::_is_a_loop($args->{loop})) {
-        $args->{loop} = UV::Loop->default();
-    }
-    $self->_init($args->{loop});
-    $self->{_loop} = $args->{loop};
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
 }
 
 sub start {
@@ -29,7 +26,17 @@ sub start {
     if (@_) {
         $self->on('prepare', shift);
     }
-    return $self->_start();
+    my $res;
+    my $err = do { #catch
+        local $@;
+        eval {
+            $res = $self->_start();
+            1;
+        }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $res;
 }
 
 1;
@@ -55,7 +62,12 @@ UV::Prepare - Prepare handles in libuv
 
   # Use a different loop
   my $loop = UV::Loop->new(); # non-default loop
-  my $prepare = UV::Prepare->new($loop);
+  my $prepare = UV::Prepare->new(
+    loop => $loop,
+    on_alloc => sub {say "alloc!"},
+    on_close => sub {say "close!"},
+    on_prepare => sub {say "prepare!"},
+  );
 
   # setup the handle's callback:
   $prepare->on(prepare => sub {say "We're prepared!!!"});
@@ -81,7 +93,7 @@ before polling for i/o.
 L<UV::Prepare> inherits all events from L<UV::Handle> and also makes the
 following extra events available.
 
-=head2 timer
+=head2 prepare
 
     $prepare->on(prepare => sub { my $invocant = shift; say "We are here!"});
     my $count = 0;
@@ -106,7 +118,12 @@ following extra methods available.
 
     my $prepare = UV::Prepare->new();
     # Or tell it what loop to initialize against
-    my $prepare = UV::Prepare->new($loop);
+    my $prepare = UV::Prepare->new(
+        loop => $loop,
+        on_alloc => sub {say "alloc!"},
+        on_close => sub {say "close!"},
+        on_prepare => sub {say "prepare!"},
+    );
 
 This constructor method creates a new L<UV::Prepare> object and
 L<initializes|http://docs.libuv.org/en/v1.x/prepare.html#c.uv_prepare_init> the
