@@ -1,29 +1,26 @@
 package UV::Timer;
 
-our $VERSION = '1.000005';
-$VERSION = eval $VERSION;
+our $VERSION = '1.000006';
 
 use strict;
 use warnings;
-use Moo;
-extends 'UV::Handle';
-
 use Carp ();
 use Exporter qw(import);
-use UV::Loop;
+use parent 'UV::Handle';
 
 our @EXPORT_OK = (@UV::Timer::EXPORT_XS,);
 
-sub BUILD {
+sub _after_new {
     my ($self, $args) = @_;
-    # add to the default set of events for a Handle object
     $self->_add_event('timer', $args->{on_timer});
 
-    unless (exists($args->{loop}) && UV::Loop::_is_a_loop($args->{loop})) {
-        $args->{loop} = UV::Loop->default();
-    }
-    $self->_init($args->{loop});
-    $self->{_loop} = $args->{loop};
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
 }
 
 sub repeat {
@@ -41,7 +38,17 @@ sub start {
     if (@_) {
         $self->on('timer', shift);
     }
-    return $self->_start($timeout, $repeat);
+    my $res;
+    my $err = do { #catch
+        local $@;
+        eval {
+            $res = $self->_start($timeout, $repeat);
+            1;
+        }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $res;
 }
 1;
 
@@ -66,7 +73,12 @@ UV::Timer - Timers in libuv
 
   # Use a different loop
   my $loop = UV::Loop->new(); # non-default loop
-  my $timer = UV::Timer->new($loop);
+  my $timer = UV::Timer->new(
+    loop => $loop,
+    on_alloc => sub {say "alloc!"},
+    on_close => sub {say "close!"},
+    on_timer => sub {say "timer!"},
+  );
 
   # setup the timer callback:
   $timer->on("timer", sub {say "We're TIMING!!!"});
@@ -115,7 +127,12 @@ following extra methods available.
 
     my $timer = UV::Timer->new();
     # Or tell it what loop to initialize against
-    my $timer = UV::Timer->new($loop);
+    my $timer = UV::Timer->new(
+        loop => $loop,
+        on_alloc => sub {say "alloc!"},
+        on_close => sub {say "close!"},
+        on_timer => sub {say "timer!"},
+    );
 
 This constructor method creates a new L<UV::Timer> object and
 L<initializes|http://docs.libuv.org/en/v1.x/timer.html#c.uv_timer_init> the
